=== modified file 'www/apps/fileservice/listing.py'
--- www/apps/fileservice/listing.py	2008-01-12 15:32:54 +0000
+++ www/apps/fileservice/listing.py	2008-01-13 12:08:48 +0000
@@ -270,7 +270,7 @@
     "ddd mmm dd, yyyy h:m a"
     """
     #return time.ctime(seconds_since_epoch)
-    return time.strftime("%a %b %d, %Y %I:%M %p",
+    return time.strftime("%a %b %d %Y, %I:%M %p",
         time.localtime(seconds_since_epoch))
 
 def make_date_nice_short(seconds_since_epoch):

=== modified file 'www/media/browser/browser.css'
--- www/media/browser/browser.css	2008-01-13 11:03:44 +0000
+++ www/media/browser/browser.css	2008-01-13 12:08:48 +0000
@@ -148,13 +148,13 @@
     text-align: center;
 }
 
-#sidepanel p, #sidepanel h1, #sidepanel h2 {
+#sidepanel p, #sidepanel h2, #sidepanel h3 {
     margin: 0;
     padding: 0;
 }
 
-#sidepanel h2 {
-    margin-top: 8px;
+#sidepanel h3 {
+    margin-top: 1em;
 }
 
 #sidepanel a {

=== modified file 'www/media/browser/browser.js'
--- www/media/browser/browser.js	2008-01-13 11:03:44 +0000
+++ www/media/browser/browser.js	2008-01-13 12:08:48 +0000
@@ -77,6 +77,11 @@
     "text/x-python",
 ];
 
+
+/* Global variables */
+
+current_path = "";
+
 /** Calls the server using Ajax, performing an action on the server side.
  * Receives the response from the server and performs a refresh of the page
  * contents, updating it to display the returned data (such as a directory
@@ -128,6 +133,25 @@
     handle_response(path, response, editmode);
 }
 
+/** Determines the "handler type" from a MIME type.
+ * The handler type is a string, either "text", "image", "audio" or "binary".
+ */
+function get_handler_type(content_type)
+{
+    if (!content_type)
+        return null;
+    if (content_type in type_handlers)
+        return type_handlers[content_type];
+    else
+    {   /* Based on the first part of the MIME type */
+        var handler_type = content_type.split('/')[0];
+        if (handler_type != "text" && handler_type != "image" &&
+            handler_type != "audio")
+            handler_type = "binary";
+        return handler_type;
+    }
+}
+
 /** Given an HTTP response object, cleans up and rebuilds the contents of the
  * page using the response data. This does not navigate away from the page, it
  * merely rebuilds most of the data.
@@ -144,6 +168,7 @@
 function handle_response(path, response, editmode)
 {
     /* TODO: Set location bar to "path" */
+    current_path = path;
     settitle(path);
 
     /* Clear away the existing page contents */
@@ -182,16 +207,7 @@
     {
         /* Treat this as an ordinary file. Get the file type. */
         var content_type = response.getResponseHeader("Content-Type");
-        var handler_type;
-        if (content_type in type_handlers)
-            handler_type = type_handlers[content_type];
-        else
-        {   /* Based on the first part of the MIME type */
-            handler_type = content_type.split('/')[0];
-            if (handler_type != "text" && handler_type != "image" &&
-                handler_type != "audio")
-                handler_type = "binary";
-        }
+        var handler_type = get_handler_type(content_type);
         /* If we're in "edit mode", always treat this file as text */
         would_be_handler_type = handler_type;
         if (editmode) handler_type = "text";

=== modified file 'www/media/browser/listing.js'
--- www/media/browser/listing.js	2008-01-13 11:16:26 +0000
+++ www/media/browser/listing.js	2008-01-13 12:08:48 +0000
@@ -30,6 +30,155 @@
 
 /** The listing object returned by the server as JSON */
 file_listing = null;
+thisdir = null;
+
+/** Updates the side-panel. Expects selected_files reflects the current
+ * selected files.
+ */
+function update_sidepanel(total_file_size_sel)
+{
+    var sidepanel = document.getElementById("sidepanel");
+    var filename;
+    var file;
+    var p;
+    /* Is this dir under svn? */
+    var under_subversion = "svnstatus" in thisdir;
+    dom_removechildren(sidepanel);
+    if (selected_files.length <= 1)
+    {
+        if (selected_files.length == 0)
+        {
+            /* Display information about the current directory instead */
+            filename = path_basename(current_path);
+            file = thisdir;
+        }
+        else if (selected_files.length == 1)
+        {
+            filename = selected_files;
+            file = file_listing[filename];
+        }
+        var filetype;
+        if ("isdir" in file && file.isdir)
+            filetype = "text/directory";
+        else if ("type" in file)
+            filetype = file.type;
+        else
+            filetype = "text/plain";
+
+        p = document.createElement("p");
+        sidepanel.appendChild(p);
+        p.appendChild(dom_make_img(mime_type_to_icon(filetype, true),
+            null, null, filetype));
+        p = dom_make_text_elem("h2", filename);
+        sidepanel.appendChild(p);
+        p = dom_make_text_elem("p", filetype);
+        sidepanel.appendChild(p);
+        if ("size" in file)
+        {
+            p = dom_make_text_elem("p", "Size: " + nice_filesize(file.size));
+            sidepanel.appendChild(p);
+        }
+        if ("mtime_nice" in file)
+        {
+            p = dom_make_text_elem("p", "Modified: " + file.mtime_nice);
+            sidepanel.appendChild(p);
+        }
+    }
+    else
+    {
+        /* Multiple files selected */
+        p = document.createElement("p");
+        sidepanel.appendChild(p);
+        p.appendChild(dom_make_img(
+            make_path(path_join(type_icons_path_large, "multi.png")),
+            null, null, "Multiple files"));
+        p = dom_make_text_elem("h2",
+            selected_files.length.toString() + " files selected");
+        sidepanel.appendChild(p);
+        p = dom_make_text_elem("p", "Total size: "
+            + nice_filesize(total_file_size_sel));
+        sidepanel.appendChild(p);
+    }
+
+    p = dom_make_text_elem("h3", "Actions");
+    sidepanel.appendChild(p);
+
+    if (selected_files.length <= 1)
+    {
+        var handler_type = null;
+        if ("type" in file)
+            handler_type = get_handler_type(file.type);
+        /* Action: Use the "files" / "edit" app */
+        if (file.isdir)
+            p = dom_make_link_elem("p", "Browse",
+                "Browse this directory in the file browser");
+        else if (handler_type == "text")
+            p = dom_make_link_elem("p", "Edit", "Edit this file");
+        else
+            p = dom_make_link_elem("p", "Browse",
+                "View this file in the file browser");
+        sidepanel.appendChild(p);
+
+        /* Action: Use the "serve" app */
+        /* TODO: Figure out if this file is executable,
+         * and change the link to "Run" */
+        p = null;
+        if (file.isdir || handler_type == "binary") {}
+        else
+            p = dom_make_link_elem("p", "View",
+                "View this file");
+        if (p)
+            sidepanel.appendChild(p);
+
+        /* Action: Use the "download" app */
+        p = null;
+        if (file.isdir)
+            p = dom_make_link_elem("p", "Download as zip",
+                "Download this directory as a ZIP file");
+        else
+            p = dom_make_link_elem("p", "Download",
+                "Download this file to your computer");
+        if (p)
+            sidepanel.appendChild(p);
+
+        p = dom_make_link_elem("p", "Rename",
+            "Change the name of this file");
+        sidepanel.appendChild(p);
+    }
+    else
+    {
+        /* Multiple files selected */
+        p = dom_make_link_elem("p", "Download as zip",
+            "Download the selected files as a ZIP file");
+        sidepanel.appendChild(p);
+    }
+
+    /* Common actions */
+    p = dom_make_link_elem("p", "Cut",
+        "Prepare to move the selected files to another directory");
+    sidepanel.appendChild(p);
+    p = dom_make_link_elem("p", "Copy",
+        "Prepare to copy the selected files to another directory");
+    sidepanel.appendChild(p);
+    p = dom_make_link_elem("p", "Paste",
+        "Paste the copied or cut files to the current directory");
+    sidepanel.appendChild(p);
+
+    /*
+     <p><a href="">Cut</a></p>
+     <p><a href="">Copy</a></p>
+     */
+    if (under_subversion)
+    {
+        p = dom_make_text_elem("h3", "Subversion");
+        sidepanel.appendChild(p);
+        /*
+     <p><a href="">Commit</a></p>
+     <p><a href="">Update</a></p>
+         */
+    }
+
+}
 
 /** Updates the side-panel and status bar to reflect the current set of
  * selected files. This is done by inspecting the states of the check boxes.
@@ -79,6 +228,9 @@
         i++;
     }
 
+    /* Write to the side-panel */
+    update_sidepanel(total_file_size_sel);
+
     /* Write to the status bar */
     var statusbar = document.getElementById("statusbar");
     var statusmsg;
@@ -197,7 +349,7 @@
     file_listing = listing;     /* Global */
 
     /* Get "." out, it's special */
-    var thisdir = listing["."];
+    thisdir = listing["."];     /* Global */
     delete listing["."];
     /* Is this dir under svn? */
     var under_subversion = "svnstatus" in thisdir;

